@@ -82,6 +82,22 @@ class GitRemoteBook(object):
         # Code(filename=file_name_in_book, language="text")
         os.chdir(self.current_working_dir)
 
+    def book_move_line(self, old_line, new_line, ori_md5, new_md5):
+        file_name_in_book = self._book_prepare()
+        if (ori_md5 == util.get_file_md5sum(file_name_in_book)):
+            util.move_line_in_file(file_name_in_book, old_line, new_line)
+            commit_message = "Move line %d to line %d" % str(old_line, new_line)
+            self._book_commit(file_name_in_book, commit_message, new_md5)
+        os.chdir(self.current_working_dir)
+
+    def book_move_line_block(self, line_begin, line_end, new_line, ori_md5, new_md5):
+        file_name_in_book = self._book_prepare()
+        if (ori_md5 == util.get_file_md5sum(file_name_in_book)):
+            util.move_line_block_in_file(file_name_in_book, line_begin, line_end, new_line)
+            commit_message = "Move line block(%d, %d) to line %d" % str(line_begin, line_end, new_line)
+            self._book_commit(file_name_in_book, commit_message, new_md5)
+        os.chdir(self.current_working_dir)
+
     def book_del_lines(self, line_numbers, ori_md5, new_md5):
         if isinstance(line_numbers, list) == False:
             line_numbers = [line_numbers]        
