@@ -16,6 +16,7 @@ class ImageRecognizer(object):
         flag_force=False,
         ratio="2.0",
         flag_autocrop=True,
+        app_name="img2txt",
     ):
         self.img_name = img_name
         self.top = crop_img_top
@@ -27,6 +28,7 @@ class ImageRecognizer(object):
         self.ratio = ratio
         self.flag_force = flag_force
         self.flag_autocrop = flag_autocrop
+        self.app_name = app_name
         self.prepare_img()
 
     def get_dst_img_file(self):
@@ -35,11 +37,42 @@ class ImageRecognizer(object):
     def get_dst_img_file_json(self):
         return "%s.json" % self.get_dst_img_file()
 
+    def checking_json_data(self):
+        dst_img_file_json = self.get_dst_img_file_json()
+        if os.path.isfile(dst_img_file_json):
+            data = json.load(open(dst_img_file_json, "r", encoding="utf-8"))
+            if ((data.__contains__("recognize_text") == False) or
+                (len(data["recognize_text"])<=0) or
+                (data.__contains__("app_name") == False) or
+                (data["app_name"] != self.app_name) or
+                (data.__contains__("flag_autocrop") == False) or
+                (data["flag_autocrop"] != self.flag_autocrop) or
+                (data.__contains__("ratio") == False) or
+                (data["ratio"] != self.ratio) or
+                (data.__contains__("crop_img_top") == False) or
+                (data["crop_img_top"] != self.top) or
+                (data.__contains__("crop_img_bottom") == False) or
+                (data["crop_img_bottom"] != self.bottom) or
+                (data.__contains__("crop_img_left") == False) or
+                (data["crop_img_left"] != self.left) or
+                (data.__contains__("crop_img_right") == False) or
+                (data["crop_img_right"] != self.right)):
+                os.remove(dst_img_file_json)
+                return False
+            else:
+                return True
+        else:
+            return False
+
     def prepare_img(self):
         dst_img_file = self.get_dst_img_file()
         if self.flag_force:
             if os.path.isfile(dst_img_file):
                 os.remove(dst_img_file)
+        else:
+            if os.path.isfile(dst_img_file):
+                if self.checking_json_data() == False:
+                    os.remove(dst_img_file)
         if os.path.isfile(dst_img_file) == False:
             # cargo install menyoki
             util.print_run_cmd(
@@ -67,31 +100,14 @@ class ImageRecognizer(object):
         return dst_img_file
 
     def recognize_text(self, app_name="img2txt"):
+        self.app_name = app_name
         dst_img_file_json = self.get_dst_img_file_json()
         # print(dst_img_file_json)
         if self.flag_force:
             if os.path.isfile(dst_img_file_json):
                 os.remove(dst_img_file_json)
         else:
-            if os.path.isfile(dst_img_file_json):
-                data = json.load(open(dst_img_file_json, "r", encoding="utf-8"))
-                if ((data.__contains__("recognize_text") == False) or
-                    (len(data["recognize_text"])<=0) or
-                    (data.__contains__("app_name") == False) or
-                    (data["app_name"] != app_name) or
-                    (data.__contains__("flag_autocrop") == False) or
-                    (data["flag_autocrop"] != self.flag_autocrop) or
-                    (data.__contains__("ratio") == False) or
-                    (data["ratio"] != self.ratio) or
-                    (data.__contains__("crop_img_top") == False) or
-                    (data["crop_img_top"] != self.top) or
-                    (data.__contains__("crop_img_bottom") == False) or
-                    (data["crop_img_bottom"] != self.bottom) or
-                    (data.__contains__("crop_img_left") == False) or
-                    (data["crop_img_left"] != self.left) or
-                    (data.__contains__("crop_img_right") == False) or
-                    (data["crop_img_right"] != self.right)):
-                    os.remove(dst_img_file_json)
+            self.checking_json_data()
         if os.path.isfile(dst_img_file_json) == False:
             # util.run_deno_cmd("js_book_util img2txt %s" % dst_img_file)
             # util.run_deno_cmd("js_book_util easyocr2txt %s" % dst_img_file)
