@@ -182,16 +182,52 @@ def add_line_in_file(
 
 def del_line_in_file(file_path, old_line_number):
     import fileinput
-
+    deleted_line = ""
     line_number = 0
     with fileinput.FileInput(file_path, inplace=True) as f:
         for line in f:
             line_number = line_number + 1
             if line_number == old_line_number:
-                pass
+                deleted_line = line
             else:
                 print(line, end="")
+    return deleted_line
 
+def del_line_block_in_file(file_path, old_line_number_begin, old_line_number_end):
+    import fileinput
+    deleted_line = ""
+    line_number = 0
+    with fileinput.FileInput(file_path, inplace=True) as f:
+        for line in f:
+            line_number = line_number + 1
+            if old_line_number_begin == line_number:
+                deleted_line = line
+            else:
+                if old_line_number_begin < line_number and line_number <= old_line_number_end:
+                    deleted_line = deleted_line + line
+                else:
+                    print(line, end="")
+    return deleted_line
+
+def move_line_in_file(file_path, old_line_number, new_line_number):
+    if (old_line_number <= new_line_number and new_line_number <= (old_line_number + 1)):
+        return ""
+    else:
+        new_line_content = del_line_in_file(file_path, old_line_number)
+        if (old_line_number > new_line_number):
+            add_line_in_file(file_path, new_line_number, new_line_content)
+        else:
+            add_line_in_file(file_path, new_line_number - 1, new_line_content)
+
+def move_line_block_in_file(file_path, old_line_number_begin, old_line_number_end, new_line_number):
+    if (old_line_number_begin <= new_line_number and new_line_number <= (old_line_number_end + 1)):
+        return
+    else:
+        new_line_content = del_line_block_in_file(file_path, old_line_number_begin, old_line_number_end)
+        if (old_line_number_begin > new_line_number):
+            add_line_in_file(file_path, new_line_number, new_line_content)
+        else:
+            add_line_in_file(file_path, new_line_number - (old_line_number_end - old_line_number_begin + 1), new_line_content)
 
 def read_text_file(file_path):
     from pathlib import Path
